@@ -45,6 +45,7 @@ function [desc, extraOpts, funcName, numFunctions] = testfunctions(k)
                            @contourPenny        , ...
                            @peaks_contourf      , ...
                            @many_random_points  , ...
+                           @double_colorbar     , ...
                            @randomWithLines     , ...
                            @double_axes         , ...
                            @double_axes2        , ...
@@ -56,6 +57,7 @@ function [desc, extraOpts, funcName, numFunctions] = testfunctions(k)
                            @zoom                , ...
                            @quiveroverlap       , ...
                            @quiverplot          , ...
+                           @quiver3plot         , ...
                            @imageplot           , ...
                            @logicalImage        , ...
                            @imagescplot         , ...
@@ -99,6 +101,7 @@ function [desc, extraOpts, funcName, numFunctions] = testfunctions(k)
                            @spherePlot          , ...
                            @surfPlot            , ...
                            @surfPlot2           , ...
+                           @superkohle          , ...
                            @meshPlot            , ...
                            @ylabels             , ...
                            @spectro             , ... % takes pretty long to LuaLaTeX-compile
@@ -192,12 +195,14 @@ function [description, extraOpts] = one_point()
   %legend(char('Multi-Line Legend Entry','Wont Work 2^2=4'))
   legend('Multi-Line Legend Entry Wont Work 2^2=4')
   xlabel({'one','two','three'});
-  ylabel({'one','two','three'});
+  ylabel({'one','° ∞', 'three'});
 
 %  plot(0.123, 0.145, 'x');
   set(gca, 'YTick', []);
   set(gca,'XTick',0:1:length(m)-1);
 
+  set(gca,'XTickLabel',{});
+
   description = 'Plot only one single point.';
   extraOpts = {};
 
@@ -344,8 +349,9 @@ end
 % =========================================================================
 function [description, extraOpts] = peaks_contourf ()
 
-  contourf( peaks(20), 10 );
+  contourf(peaks(20), 10);
   colorbar();
+  legend('my legend');
 %    colorbar('NorthOutside');
 %    colorbar('SouthOutside');
 %    colorbar('WestOutside');
@@ -356,6 +362,33 @@ function [description, extraOpts] = peaks_contourf ()
   description = 'Test the contourfill plots.';
   extraOpts = {};
 
+end
+% =========================================================================
+function [description, extraOpts] = double_colorbar()
+
+  vspace = linspace(-40,40,20);
+  speed_map = rand(20);
+  Q1_map = rand(20);
+
+  subplot(1, 2, 1);
+  contour(vspace(9:17),vspace(9:17),speed_map(9:17,9:17),20)
+  colorbar
+  axis tight
+  axis square
+  xlabel('$v_{2d}$')
+  ylabel('$v_{2q}$')
+
+  subplot(1, 2, 2)
+  contour(vspace(9:17),vspace(9:17),Q1_map(9:17,9:17),20)
+  colorbar
+  axis tight
+  axis square
+  xlabel('$v_{2d}$')
+  ylabel('$v_{2q}$')
+
+  description = 'Double colorbar.';
+  extraOpts = {};
+
 end
 % =========================================================================
 function [description, extraOpts] = randomWithLines()
@@ -593,7 +626,9 @@ function [description, extraOpts] = bars()
   numBars = 3;
   data = round(100 * rand(numEntries, numBars));
 
-  bar(bins,data, 1.5);
+  b = bar(bins,data, 1.5);
+
+  set(b(1),'FaceColor','m','EdgeColor','none')
 
   description = 'Plot with bars.';
   extraOpts = {};
@@ -673,7 +708,7 @@ function [description, extraOpts] = stemplot2()
 
 end
 % =========================================================================
-function [description, extraOpts] = stairsplot ()
+function [description, extraOpts] = stairsplot()
 
   x = linspace(-2*pi,2*pi,40);
   stairs(x,sin(x))
@@ -683,7 +718,7 @@ function [description, extraOpts] = stairsplot ()
 
 end
 % =========================================================================
-function [description, extraOpts] = quiverplot ()
+function [description, extraOpts] = quiverplot()
 
   [X,Y] = meshgrid(-2:.2:2);
   Z = X.*exp(-X.^2 - Y.^2);
@@ -697,6 +732,31 @@ function [description, extraOpts] = quiverplot ()
   description = 'A combined quiver/contour plot of $x\exp(-x^2-y^2)$.' ;
   extraOpts = {};
 
+end
+% =========================================================================
+function [description, extraOpts] = quiver3plot()
+
+  vz = 10;            % Velocity
+  a = -32;            % Acceleration
+
+  t = 0:.1:1;
+  z = vz*t + 1/2*a*t.^2;
+
+  vx = 2;
+  x = vx*t;
+  vy = 3;
+  y = vy*t;
+
+  u = gradient(x);
+  v = gradient(y);
+  w = gradient(z);
+  scale = 0;
+  quiver3(x,y,z,u,v,w,scale)
+  view([70 18])
+
+  description = 'Three-dimensional quiver plot.' ;
+  extraOpts = {};
+
 end
 % =========================================================================
 function [description, extraOpts] = quiveroverlap ()
@@ -745,18 +805,19 @@ end
 % =========================================================================
 function [description, extraOpts] = imageplot ()
 
-  n       = 10;
+  n = 10;
   density = 0.5;
 
-  subplot( 1, 2, 1 );
-  A       = sprand( n, n, density );
+  subplot(1,2,1);
+  A = sprand( n, n, density );
   imagesc( A );
 
-  subplot( 1, 2, 2 );
-  A       = sprand( n, n, density );
+  subplot(1,2,2);
+  A = sprand( n, n, density );
   imagesc( A );
 
   description = 'An image plot of matrix values.' ;
+  %extraOpts = {'imagesAsPng', false};
   extraOpts = {};
 
 end
@@ -925,12 +986,15 @@ end
 % =========================================================================
 function [description, extraOpts] = errorBars ()
 
-  X = 0:pi/10:pi;
-  Y = sin(X);
-  E = std(Y)*ones(size(X));
-  errorbar(X,Y,E)
+  data = 1:10;
+  eH = rand(10,1);
+  eL = rand(10,1);
+  %hold on;
+  %bar(1:10, data)
+  errorbar(1:10, data, eL, eH, '.')
 
-  description = 'Generic error bar plot.' ;
+
+  description = 'Generic error bar plot.';
   extraOpts = {};
 
 end
@@ -942,7 +1006,7 @@ function [description, extraOpts] = errorBars2 ()
   e = std( data, 1, 2 );
   errorbar( y, e, 'xr' );
 
-  description = 'Another error bar example.' ;
+  description = 'Another error bar example.';
   extraOpts = {};
 
 end
@@ -1004,6 +1068,14 @@ function [description, extraOpts] = legendsubplots()
 end
 % =========================================================================
 function [description, extraOpts] = legendsubplots2()
+
+  if isempty(which('tf'))
+      fprintf( 'function "tf" not found. Abort.\n\n' );
+      description = [];
+      extraOpts = {};
+      return
+  end
+
   Rc=1;
   C=1.5e-6; %F
 
@@ -1057,6 +1129,13 @@ end
 % =========================================================================
 function [description, extraOpts] = rlocusPlot()
 
+  if isempty(which('tf'))
+      fprintf( 'function "tf" not found. Abort.\n\n' );
+      description = [];
+      extraOpts = {};
+      return
+  end
+
   s=tf('s');
   rlocus(tf([1 1],[4 3 1]))
 
@@ -1235,8 +1314,11 @@ end
 % =========================================================================
 function [description, extraOpts] = scatterPlotRandom()
 
-  x = randn( 10, 2 );
-  scatter( x(:,1), x(:,2)  );
+  n=1:100;
+  scatter(n, n, 1000*rand(length(n),1), n.^8);
+  colormap autumn;
+  %x = randn( 10, 2 );
+  %scatter( x(:,1), x(:,2)  );
   description = 'Generic scatter plot.';
   extraOpts = {};
 
@@ -1321,9 +1403,20 @@ function [description, extraOpts] = surfPlot()
   axis([-3 3 -3 3 -10 5])
   set(gca,'View',[-37.5,36]);
 
-  hc = colorbar;
+  hc = colorbar('YTickLabel', ...
+                {'Freezing','Cold','Cool','Neutral',...
+                 'Warm','Hot','Burning','Nuclear'});
   set(get(hc,'Xlabel'),'String','Multitude');
   set(get(hc,'Ylabel'),'String','Magnitude');
+  set(hc,'YTick',0:0.7:7);
+  set(hc,'YTickLabel',...
+         {'-0.8' '-0.6' '-0.4' '-0.2' '0.0' ...
+          '0.2' '0.4' '0.6' '0.8' '0.10' '0.12'});
+
+  set(get(hc,'Title'),...
+      'String', 'k(u,v)', ...
+      'FontSize', 12, ...
+      'interpreter', 'tex');
 
   xlabel( 'x' )
   ylabel( 'y' )
@@ -1347,6 +1440,40 @@ function [description, extraOpts] = surfPlot2()
   extraOpts = {};
 end
 % =========================================================================
+function [description, extraOpts] = superkohle()
+
+  x1=0;
+  x2=pi;
+  y1=0;
+  y2=pi;
+  omegashape = [2 2 2 2             % 2 = line segment; 1 = circle segment; 4 = elipse segment
+              x1 x2 x2 x1         % start point x
+              x2 x2 x1 x1         % end point x
+              y1 y1 y2 y2         % start point y
+              y1 y2 y2 y1         % end point y
+              1 1 1 1
+              0 0 0 0];
+  [xy,edges,tri] = initmesh(omegashape,'Hgrad',1.05);
+  mmin = 1;
+  while size(xy,2) < mmin
+      [xy,edges,tri] = refinemesh(omegashape,xy,edges,tri);
+  end
+  m = size(xy,2);
+  x = xy(1,:)';
+  y = xy(2,:)';
+  y0 = cos(x).*cos(y);
+
+  pdesurf(xy,tri,y0(:,1));
+  title('y_0');
+  xlabel('x1 axis');
+  ylabel('x2 axis');
+  axis([0 pi 0 pi -1 1]);
+  grid on;
+
+  description = 'Superkohle plot.';
+  extraOpts = {};
+end
+% =========================================================================
 function [description, extraOpts] = meshPlot()
   [X,Y,Z] = peaks(30);
   mesh(X,Y,Z)
@@ -1379,7 +1506,7 @@ function [description, extraOpts] = spectro()
 
   % In the original test case, this is 0:0.001:2, but that takes forever
   % for LaTeX to process.
-  if ~exist('chirp', 'builtin')
+  if isempty(which('chirp'))
       fprintf( 'chirp() not found. Abort.\n\n' );
       description = [];
       extraOpts = {};
